pub struct ManagedHeap { /* private fields */ }Expand description
A virtual Heap which can be garbage collected by calling gc().
Implementations
Sourceimpl ManagedHeap
impl ManagedHeap
pub fn num_used_blocks(&self) -> usize
pub fn num_free_blocks(&self) -> usize
pub fn total_size(&self) -> usize
pub fn used_size(&self) -> usize
Sourceimpl ManagedHeap
impl ManagedHeap
Sourcepub fn alloc(&mut self, size: HalfWord) -> Option<Address>
pub fn alloc(&mut self, size: HalfWord) -> Option<Address>
Takes the blocksize as a number of usize values.
The size in bytes of the block is therefore size * mem::size_of::