ManagedHeap

Struct ManagedHeap 

pub struct ManagedHeap { /* private fields */ }
A virtual Heap which can be garbage collected by calling gc().

Implementations

Source

impl ManagedHeap

pub fn new(size: usize) -> Self

Expects the heap size in bytes.

Source

impl ManagedHeap

pub fn num_used_blocks(&self) -> usize

pub fn num_free_blocks(&self) -> usize

pub fn total_size(&self) -> usize

pub fn used_size(&self) -> usize

Source

impl ManagedHeap

pub fn alloc(&mut self, size: HalfWord) -> Option<Address>

Takes the blocksize as a number of usize values. The size in bytes of the block is therefore size * mem::size_of::() (technically + one more usize to store information about the block)

pub fn gc<T>(&mut self, roots: &mut [&mut dyn GcRoot<T>])

Run the mark & sweep garbage collector. roots should return an iterator over all objects still in use. If an object is neither returned by one of the roots, nor from another object in the root.children(), it gets automatically freed.